﻿using System;
using System.Collections.Generic;
using System.Diagnostics.Tracing;
using System.Linq;
using System.Threading.Tasks;

namespace EventMakerRazor.Models
{
    public class FakeEventRepository
    {
        private static int nextId = 1;

        private static FakeEventRepository _instance;

        public static FakeEventRepository Instance
        {
            get { return _instance ?? (_instance = new FakeEventRepository()); }
        }
        
        public List<Event> Events { get; }
        
        private FakeEventRepository()
        {
            Events = new List<Event>();
            Events.Add(new Event() { Id = nextId++, Name = "Roskilde Festival", City="Roskilde", Description = "Masser af musik", DateTime = new DateTime(2021, 6, 1)});
            Events.Add(new Event() { Id = nextId++, Name = "Copenhagen Marathon", City = "Copenhagen", Description = "Running 42 km in CPH", DateTime = new DateTime(2021, 5, 16, 9, 30, 0) });
            Events.Add(new Event() { Id = nextId++, Name = "KMD Ironman CPH", City = "CPH", Description = "Svøm 3.8km, 180 km Cykling og 42 km Løb", DateTime = new DateTime(2021, 8, 22) });
        }

        public void AddEvent(Event ev)
        {
            ev.Id = nextId++;
            Events.Add(ev);
        }

        public Event GetEvent(int id)
        {
            foreach (Event e in Events)
            {
                if (e.Id == id) return e;
            }
            return new Event();
        }

        public void UpdateEvent(Event eEvent)
        {
            if (eEvent != null)
            {
                foreach (Event e in Events)
                {
                    if (e.Id == eEvent.Id)
                    {
                        e.Name = eEvent.Name;
                        e.Description = eEvent.Description;
                        e.City = eEvent.City;
                        e.DateTime = eEvent.DateTime;
                    }
                }
            }
        }
        public Event DeleteEvent(int eventId)
        {
            Event eventToBeDeleted = null;
            foreach (Event e in Events)
            {
                if (e.Id == eventId)
                {
                    eventToBeDeleted = e;
                    break;
                }
                
            }

            if (eventToBeDeleted != null)
            {
                Events.Remove(eventToBeDeleted);
            }

            return eventToBeDeleted;
        }
    }
}
